@@ -16,8 +16,29 @@ links {
 language "C++"
 
 files {
-	"**.cpp",
-	"**.h",
+	"PhysicsClient.cpp",
+	"PhysicsClientSharedMemory.cpp",
+	"PhysicsClientExample.cpp",
+	"PhysicsServerExample.cpp",
+	"PhysicsServerSharedMemory.cpp",
+	"PhysicsServerSharedMemory.h",
+	"PhysicsServer.cpp",
+	"PhysicsServer.h",
+	"main.cpp",
+	"PhysicsClientC_API.cpp",
+	"PhysicsServer.cpp",
+	"PosixSharedMemory.cpp",
+	"Win32SharedMemory.cpp",
+	"PhysicsDirect.cpp",
+	"PhysicsDirect.h",
+	"PhysicsDirectC_API.cpp",
+	"PhysicsDirectC_API.h",
+	"PhysicsLoopBack.cpp",
+	"PhysicsLoopBack.h",
+	"PhysicsLoopBackC_API.cpp",
+	"PhysicsLoopBackC_API.h",
+	"PhysicsServerCommandProcessor.cpp",
+	"PhysicsServerCommandProcessor.h",
 	"../Importers/ImportURDFDemo/ConvertRigidBodies2MultiBody.h",
 	"../Importers/ImportURDFDemo/MultiBodyCreationInterface.h",
 	"../Importers/ImportURDFDemo/MyMultiBodyCreator.cpp",
